<?php
class Teqpay_TeqpayPos_PaymentController extends Mage_Core_Controller_Front_Action
{
    public function redirectAction()
    {
        $model = Mage::getModel('teqpaypos/paymentmethod')->form();

        $sandbox = Mage::getStoreConfig('payment/teqpaypos/sandbox');

        $url = $sandbox == 1 ? 'https://merchant-test.teqpay.com/api/teqpay/paywithcommonpage' : 'https://merchant.teqpay.com/api/teqpay/paywithcommonpage';
        if(isset($model['cardData'])){
            $url = $sandbox == 1 ? 'https://merchant.teqpay.com/api/teqpay/payment' : 'https://merchant-test.teqpay.com/api/teqpay/payment';
        }

        $json = json_encode($model);

        $response = $this->curl($url, 'POST', $json);
  
        if($response['Result'] == true){
            echo ("<script>location.href='" . $response['PaymentData']['PaymentUrl'] . "'</script>");
            exit;
        } else {
            Mage::getSingleton('core/session')->addError($response['ResultMessage']);

            $orderId = Mage::getSingleton('checkout/session')->getLastRealOrderId();
            $order = Mage::getSingleton('sales/order')->loadByIncrementId($orderId);

            $this->addCart($order, $response);
            header("Location: /");
            die();
        }
        
    }

    public function responseAction()
    {
        $params = $this->getRequest()->getPost();

        $order = Mage::getSingleton('sales/order')->loadByIncrementId($this->getRequest()->getParam('order_id'));

        if ($params['Result'] == true) {
            $check = $this->checkPayment($order->getIncrementId());
            if($check === true){
                $order->setState(Mage_Sales_Model_Order::STATE_PROCESSING, true)->save();
                try {
                    $order->sendNewOrderEmail();
                    
                } catch (Exception $e) {
                    Mage::log($e->getMessage(), null, 'teqpay.error.log', true);
                }

                header("Location: /checkout/onepage/success");
                die();
            } else {
                $this->addCart($order, $params);
                header("Location: /checkout/cart");
                die();
            }
        } else {
            $this->addCart($order, $params);
            header("Location: /checkout/cart");
            die();
        }
    }

    private function addCart($order, $params)
    {
        foreach ($order->getAllItems() as $item) {
            $product = Mage::getModel('catalog/product')->load($item->getProductId());

            $params = [
                'product' => $product->getId(),
                'qty' => $item->getQtyOrdered(),
            ];

            $cart = Mage::getModel('checkout/cart');
            $cart->init();
            $cart->addProduct($product, $params);
            $cart->save();

            $quote = Mage::getModel('checkout/session')->getQuote();
            $quote->collectTotals()->save();
        }

        $order->setState(Mage_Sales_Model_Order::STATE_CANCELED, true)->save();
        Mage::getSingleton('core/session')->addError($params['ResultMessage']);
    }

    public function installmentAction()
    {
        $order = Mage::getSingleton('checkout/session')->getQuote();
        //$order = Mage::getSingleton('sales/order')->loadByIncrementId($orderId);

        $sandbox = Mage::getStoreConfig('payment/teqpaypos/sandbox');

        $url = $sandbox == 1 ? 'https://merchant-test.teqpay.com/api/teqpay/installmentinfo' : 'https://merchant.teqpay.com/api/teqpay/installmentinfo';



        $array = [
            'cardNo' => substr($_GET['card'], 0, 6),
            'price' => $order->getGrandTotal(),
            'language' => 'TR'
        ];

        $response = $this->curl($url, 'POST', json_encode($array));

        $option = '';
        if($response['Result'] == 1){
            foreach ($response['Details'] as $key => $i) {

                if ($key == 0) {
                    $option .= "<option value='1'>Tek Çekim (" . $i['AmountToPaid'] . ")</option>";
                } else {
                    $option .= "<option value='" . $i['Installment'] . "'>" . $i['Installment'] . " Taksit (" . $i['AmountToPaid'] . ")</option>";
                }
            }
        } else {
            $option .= $option .= "<option value='1'>Tek Çekim (" . number_format($order->getGrandTotal(), 2) . ")</option>";
        }
        

        echo $option;
    }

    private function checkPayment($order_id)
    {
        $sandbox = Mage::getStoreConfig('payment/teqpaypos/sandbox');
        $url = $sandbox == 1 ? 'https://merchant-test.teqpay.com/api/teqpay/paymentcheck' : 'https://merchant.teqpay.com/api/teqpay/paymentcheck';

        $lang = explode(
            '_',
            Mage::app()
                ->getLocale()
                ->getLocaleCode()
        );
        $post = [
            "ConversationId" => $order_id,
            "language" => end($lang)
        ];

        $json = json_encode($post);

        $response = $this->curl($url, $method, $json);

        if($response['Details']['OrderStatusCode'] == 1){
            return true;
        }

        return false;
    }

    private function curl($url, $method, $json)
    {
        $api_key = Mage::getStoreConfig('payment/teqpaypos/apikey');
        $secret_key = Mage::getStoreConfig('payment/teqpaypos/secretkey');

        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_VERBOSE => true,
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => $method,
            CURLOPT_POSTFIELDS => $json,
            CURLOPT_HTTPHEADER => [
              "Content-Type: application/json",
              "ApiKey: {$api_key}",
              "SecretKey: {$secret_key}",
            ]
        ]);

        $response = curl_exec($curl);
		$response = json_decode($response, true);
        curl_close($curl);

        return $response;
    }
}
